# OrganisationSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**organisation_reference** | **str** |  | 
**organisation_status** | **AllOfOrganisationSummaryResponseOrganisationStatus** |  | [optional] 
**organisation_status_string** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

